#
# spec file for package python-thriftpy2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-thriftpy2
Version:        0.5.2
Release:        1.2
Summary:        Pure python implementation of Apache Thrift
License:        MIT
URL:            https://github.com/Thriftpy/thriftpy2
Source0:        https://github.com/Thriftpy/thriftpy2/archive/v%{version}.tar.gz
Source1:        new_certs.tar.xz
# PATCH-FIX-UPSTREAM 0001-Use-SO_REUSEPORT-only-for-AF_INET-sockets.patch gh#Thriftpy/thriftpy2#303
Patch1:         0001-Use-SO_REUSEPORT-only-for-AF_INET-sockets.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module ply >= 3.4}
BuildRequires:  %{python_module pytest >= 2.8}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module tornado >= 5.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ply >= 3.4
Requires:       python-six
Recommends:     python-tornado >= 5.0
Recommends:     python-toro >= 0.6
%python_subpackages

%description
ThriftPy is a pure python implementation of Apache Thrift in a
pythonic way.

%prep
%autosetup -p1 -n thriftpy2-%{version}

tar xv -C tests/ssl -f %{SOURCE1}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%{python_expand # remove devel files
find %{buildroot}%{$python_sitearch} -name '*.h' -exec rm {} \;
find %{buildroot}%{$python_sitearch} -name '*.c' -exec rm {} \;
}

%check
# the two tests fail in OBS on timeout
# test_asynchronous_exception/test_asynchronous_result - needs old tornado to work
donttest="test_able_to_communicate or test_zero_length_string or test_asynchronous_exception or test_asynchronous_result or test_api_ipv6"
# Requires python-pytest-reraise
donttest+=" or test_load_in_sub_thread or test_load_fp_in_sub_thread"

cd tests
%pytest_arch -k "not ($donttest)"

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%{python_sitearch}/thriftpy2
%{python_sitearch}/thriftpy2-%{version}.dist-info

%changelog
* Wed Feb 26 2025 Daniel Garcia <daniel.garcia@suse.com>
- Add patch 0001-Use-SO_REUSEPORT-only-for-AF_INET-sockets.patch to
  make it compatible with latest cpython. gh#Thriftpy/thriftpy2#303
- Update to 0.5.2:
  * Fix an issue where loading a thrift file in a sub-thread will cause an error with load_fp.
  * Move static metadata from setup.py to pyproject.toml.
  * Using a thread pool to avoid TAsyncSocket.open block the event loop.
- 0.5.1:
  * Fix an issue where loading a thrift file in a sub-thread will cause an error.
  * Some typo fixes.
* Wed May 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.5.0:
  * Dropped Python2 and Python3.5 Support.
  * Added SASL transport client.
  * Add submodule to sys.path when loading child idl file.
  * Support cythonized module on Windows.
  * Support using ipv6 in make_client/make_server method.
  * Basic multi-thread support in parser.
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
- Disable additional tests that require internet connection
  * test_api_ipv6
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.4.20:
  * Fix another compatibility issue with legacy Python.
  * Fix a compatibility issue with legacy Python.
  * Make the import hook compatible with Python3.12.
  * Added a ``strict_decode`` option to all protocols to force all
    strings in the response to be decoded to ``str``.
  * Allow annotations in the ``Union`` type.
  * Fixed the ``message_type`` in oneway request.
  * Fix Cython build error in latest Python3 version
- Drop restriction on Cython.
- Switch to pyproject macros.
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- restrict to older cython
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove .c and .h devel files from python package distribution.
- Update to 0.4.16:
  * Fix unexpected binary type id in TBinaryTransport serialization
- versuib 0.4.15:
  * Support Apache JSON protocol and binary type
  * Replace "yield from" syntax to "await"
  * Fix some socket leaking cases in aio support
* Tue Oct 26 2021 Matej Cepl <mcepl@suse.com>
- Update to 0.4.14:
  - revert support Apache JSON protocol and binary type, via
    2-#157.
  - Support Apache JSON protocol and binary type, via 2-#139.
  - Fix HTTP_URI typo in http.py, via 2-#148.
  - Support custom headers for HTTP, via 2-#149.
  - Support raising TApplicationException in user handlers, via
    2-#154.
  - Support include files with dot in name, via 2-#125.
- Add new SSL certificates in new_certs.tar.xz
* Thu Mar 26 2020 pgajdos@suse.com
- version update to 0.4.11
  - Support Cython in HTTP and fix TCyBufferedTransport early flush issue, via `2-#129`_.
  - Fix exception handling in TProcessor, via `2-#128`_.
  - Rename socket_timeout to timeout for compatibility, via `2-#115`_.
* Tue Jan 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.10:
  * various bugfixes all around
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python dbm dependency instead of legacy gdbm
- Tweak up the dependencies to not be unresolvable
* Tue Oct  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.7:
  * minor bugfixes
* Thu Sep 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip two tests that timeout in OBS build
* Thu Sep 19 2019 Tomáš Chvátal <tchvatal@suse.com>
- Pull in toro as a dep and build also with tornado 4.x
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Rename to python-thriftpy2 as thriftpy was deprecated
- Drop patch tornado_5.patch
* Tue Jul 17 2018 mimi.vx@gmail.com
- add tornado_5.patch to build with tornado-5.x
* Mon May 22 2017 toddrme2178@gmail.com
- Initial version
